aboutsummaryrefslogtreecommitdiff
path: root/scm
diff options
context:
space:
mode:
authorSergey Poznyakoff <gray@gnu.org.ua>2011-06-20 17:20:55 +0300
committerSergey Poznyakoff <gray@gnu.org.ua>2011-06-20 17:21:58 +0300
commit338097b8af7c7095db714782ac864ad9f0584b0f (patch)
tree9d849e31b537a9808e0e6cfe793b1595f62bb5d0 /scm
parentb6bbb4f2cf0144aa58701cd2b46277838743a277 (diff)
downloadellinika-338097b8af7c7095db714782ac864ad9f0584b0f.tar.gz
ellinika-338097b8af7c7095db714782ac864ad9f0584b0f.tar.bz2
Minor stylistic change: use "stem" for \thema rhmatos.
Diffstat (limited to 'scm')
-rw-r--r--scm/verbop.scm18
1 files changed, 9 insertions, 9 deletions
diff --git a/scm/verbop.scm b/scm/verbop.scm
index 8308d70..464c384 100644
--- a/scm/verbop.scm
+++ b/scm/verbop.scm
@@ -131,7 +131,7 @@ exec ${GUILE-guile} -l $0 -c "(apply $main (command-line))" "$@"
(define (conjugation-set key val)
(let ((elt (cond
- ((not (eq? key #:root))
+ ((not (eq? key #:stem))
(cons key val))
((and conjugation (assoc (car val) conjugation)) =>
(lambda (entry)
@@ -229,11 +229,11 @@ VALUES (~Q,~Q,~Q,~Q,~Q)"
ident))
(define (flush-mood mood vstr)
- (if (eq? (car mood) #:root)
+ (if (eq? (car mood) #:stem)
(for-each
(lambda (val)
(ellinika:sql-query
- "INSERT INTO irregular_root (verb,voice,thema,root) \
+ "INSERT INTO irregular_stem (verb,voice,thema,stem) \
VALUES (~Q,~Q,~Q,~Q)"
(verb-get #:verb)
vstr
@@ -609,17 +609,17 @@ VALUES (~Q,~Q,~Q,~Q)"
(conjugation-set "imp" (get-mood))
#f)
;;; <aor>root</aor> - Define aorist root
(xmltrans:end-tag
"aor"
(tag attr text)
(check-parent tag "act" "pas")
- (conjugation-set #:root (cons "aor" text))
+ (conjugation-set #:stem (cons "aor" text))
#f)
-;;; <root theme="aor|sub|pres">root</root> - Define aorist root
+;;; <stem theme="aor|sub|pres">stem</stem> - Define aorist stem
(xmltrans:end-tag
- "root"
+ "stem"
(tag attr text)
(check-parent tag "act" "pas")
(let ((theme (xmltrans:attr attr "theme")))
@@ -630,7 +630,7 @@ VALUES (~Q,~Q,~Q,~Q)"
((or (string=? theme "aor")
(string=? theme "sub")
(string=? theme "pres"))
- (conjugation-set #:root (cons theme text)))
+ (conjugation-set #:stem (cons theme text)))
(else
(xmltrans:parse-error #f "Unknown verb theme")
(mark-invalid))))
@@ -835,7 +835,7 @@ Informational options:
(ellinika:sql-query "DELETE FROM verbflect where ident > 99")
(ellinika:sql-query "DELETE FROM verbclass")
(ellinika:sql-query "DELETE FROM verbtense")
- (ellinika:sql-query "DELETE FROM irregular_root")
+ (ellinika:sql-query "DELETE FROM irregular_stem")
(ellinika:sql-query "DELETE FROM individual_verb")))
(set! class-list
@@ -609,17 +609,17 @@ VALUES (~Q,~Q,~Q,~Q)"
(conjugation-set "imp" (get-mood))
#f)
-;;; <aor>root</aor> - Define aorist root
+;;; <aor>stem</aor> - Define aorist stem
(xmltrans:end-tag
"aor"

Return to:

Send suggestions and report system problems to the System administrator.